Stan Math Library: stan/math/prim/scal/err/domain_error_vec.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
domain_error_vec.hpp File Reference
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/scal/meta/value_type.hpp>`
`#include <stan/math/prim/scal/meta/error_index.hpp>`
`#include <stan/math/prim/scal/meta/get.hpp>`
`#include <sstream>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::domain_error_vec (const char *function, const char *name, const T &y, const size_t i, const char *msg1, const char *msg2)
| Throw a domain error with a consistently formatted message. More...
template<typename T >
void | stan::math::domain_error_vec (const char *function, const char *name, const T &y, const size_t i, const char *msg)
| Throw a domain error with a consistently formatted message. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.